==> krename-2.8.3.tar.bz2: krename-2.8.3/krename/ProgressDialog.h <==
/***************************************************************************
                          ProgressDialog.h  -  description
                             -------------------
    begin                : Die Mai 15 15:34:19 CEST 2001
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PROGRESSDIALOG_H
#define PROGRESSDIALOG_H

#include <qwidget.h>

class KRenameImpl;
class KListView;
class KPushButton;
class QStringList;
class QStrList;
class QString;
class QHBoxLayout;
class QVBoxLayout;
class ProgressDialog : public QWidget
{ 
    Q_OBJECT
    public:
        ProgressDialog( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
        ~ProgressDialog();

        void setDestination( QString dir ) {
            m_dest = dir;
        }

        void setRenamedFiles( QStringList* list ) {
            renamedFiles = list;
        }

        void done();
        void print( QString text, QString pixmap = 0 );
        void error( QString text );
        void warning( QString text );

    public slots:
        void show();
        
    private slots:
        void quitAll();
        void restart();
        void again();
        void openDest();

    private:
        QString count();

    protected:
        QStringList* renamedFiles;
        QString m_dest;
        int m_count;

        KListView* display;
        KPushButton* buttonClose;
        KPushButton* buttonRestart;
        KPushButton* buttonAgain;
        KPushButton* buttonOpenDest;

        QVBoxLayout* ProgressDialogLayout;
        QHBoxLayout* Layout1;
};

#endif // PROGRESSDIALOG_H

==> krename-3.0.5.tar.bz2: krename-3.0.5/krename/ProgressDialog.h <==
/***************************************************************************
                          ProgressDialog.h  -  description
                             -------------------
    begin                : Die Mai 15 15:34:19 CEST 2001
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PROGRESSDIALOG_H
#define PROGRESSDIALOG_H

#include <qwidget.h>
#include <kurl.h>

typedef struct RenamedList
{
    KURL src;
    KURL dst;
        
    bool dir;    
    bool error;
};

class KRenameImpl;
class KListView;
class KPopupMenu;
class KPushButton;
class QProgressBar;
class QStringList;
class QStrList;
class QString;
class QTimer;
class QHBoxLayout;
class QVBoxLayout;
class ProgressDialog : public QWidget
{ 
    Q_OBJECT
    public:
        ProgressDialog( QWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
        ~ProgressDialog();

        void setProgressTotalSteps( int t );
        void setProgress( int p );

        inline bool wasCancelled() const { return m_canceled; }

        inline void setDestination( KURL dir ) {
            m_dest = dir;
        }

        inline void setRenamedFiles( RenamedList* list, unsigned int size ) {
            renamedFiles = list;
            m_size = size;
        }
        
        inline void setCreatedDirectories( KURL::List list ) {
            m_created = list;
        }

        void done( int errors, int successfull, bool allowundo );
        void print( QString text, QString pixmap = 0 );
        void error( QString text );
        void warning( QString text );
        
    public slots:
        void show();
        
    private slots:
        void quitAll();
        void restart();
        void again();
        void unAgain();
        void allAgain();
        void openDest();
        void canceled();
        void undo();
        void slotTimer();
        
    private:
        QString count();
        const QString simplify( const QString & text );
        
    protected:
        RenamedList* renamedFiles;
        unsigned int m_size;
        
        KURL m_dest;
        int m_count;
        bool m_canceled;
        KURL::List m_created;
        
        QTimer* m_timer;
        
        KListView* display;
        KPushButton* buttonClose;
        KPushButton* buttonRestart;
        KPushButton* buttonOpenDest;
        KPushButton* buttonUndo;
        KPushButton* buttonCancel;
        KPopupMenu* mnuButton;

        QProgressBar* bar;

        QVBoxLayout* ProgressDialogLayout;
        QHBoxLayout* Layout1;
};

#endif // PROGRESSDIALOG_H
